@@ -3,7 +3,7 @@
  *                                                                         *
  *   Copyright (C) 2007 by Robert Gruber                                   *
  *   rgruber@users.sourceforge.net                                         *
- *                                                                         *
+ *   Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>                    *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -16,10 +16,6 @@
 
 #include <QDialog>
 
-namespace Ui {
-class SnippetDialog;
-}
-
 class KActionCollection;
 
 class QAbstractItemModel;
@@ -27,6 +23,7 @@ class QModelIndex;
 class QPushButton;
 
 namespace MailCommon {
+class SnippetWidget;
 class SnippetDialog : public QDialog
 {
     Q_OBJECT
@@ -36,29 +33,49 @@ public:
     ~SnippetDialog();
 
     void setName(const QString &name);
-    QString name() const;
+    Q_REQUIRED_RESULT QString name() const;
 
     void setText(const QString &text);
-    QString text() const;
+    Q_REQUIRED_RESULT QString text() const;
+
+    void setSubject(const QString &text);
+    Q_REQUIRED_RESULT QString subject() const;
 
     void setKeySequence(const QKeySequence &sequence);
-    QKeySequence keySequence() const;
+    Q_REQUIRED_RESULT QKeySequence keySequence() const;
+
+    void setKeyword(const QString &keyword);
+    Q_REQUIRED_RESULT QString keyword() const;
+
+    void setTo(const QString &keyword);
+    Q_REQUIRED_RESULT QString to() const;
+
+    void setCc(const QString &keyword);
+    Q_REQUIRED_RESULT QString cc() const;
+
+    void setBcc(const QString &keyword);
+    Q_REQUIRED_RESULT QString bcc() const;
 
     void setGroupModel(QAbstractItemModel *model);
 
     void setGroupIndex(const QModelIndex &index);
-    QModelIndex groupIndex() const;
+    Q_REQUIRED_RESULT QModelIndex groupIndex() const;
 
+    void setAttachment(const QString &keyword);
+    Q_REQUIRED_RESULT QString attachment() const;
 private Q_SLOTS:
     void slotTextChanged();
     void slotGroupChanged();
 
 private:
     bool snippetIsValid() const;
+    void writeConfig();
+    void readConfig();
 
     KActionCollection *mActionCollection = nullptr;
-    Ui::SnippetDialog *mUi = nullptr;
+    SnippetWidget *mSnippetWidget = nullptr;
     QPushButton *mOkButton = nullptr;
+    bool mInGroupMode = false;
 };
 }
 #endif
